<?php

if ( ! function_exists('vibez_elated_footer_options_map') ) {
	/**
	 * Add footer options
	 */
	function vibez_elated_footer_options_map() {

		vibez_elated_add_admin_page(
			array(
				'slug' => '_footer_page',
				'title' => esc_html__('Footer', 'vibez'),
				'icon' => 'fa fa-sort-amount-asc'
			)
		);

		$footer_panel = vibez_elated_add_admin_panel(
			array(
				'title' => esc_html__('Footer', 'vibez'),
				'name' => 'footer',
				'page' => '_footer_page'
			)
		);

		vibez_elated_add_admin_field(
			array(
				'type' => 'yesno',
				'name' => 'footer_in_grid',
				'default_value' => 'yes',
				'label' => esc_html__('Footer in Grid', 'vibez'),
				'description' => esc_html__('Enabling this option will place Footer content in grid', 'vibez'),
				'parent' => $footer_panel,
			)
		);

		vibez_elated_add_admin_field(
			array(
				'type' => 'yesno',
				'name' => 'show_footer_top',
				'default_value' => 'yes',
				'label' => esc_html__('Show Footer Top', 'vibez'),
				'description' => esc_html__('Enabling this option will show Footer Top area', 'vibez'),
				'args' => array(
					'dependence' => true,
					'dependence_hide_on_yes' => '',
					'dependence_show_on_yes' => '#eltdf_show_footer_top_container'
				),
				'parent' => $footer_panel,
			)
		);

		$show_footer_top_container = vibez_elated_add_admin_container(
			array(
				'name' => 'show_footer_top_container',
				'hidden_property' => 'show_footer_top',
				'hidden_value' => 'no',
				'parent' => $footer_panel
			)
		);

		vibez_elated_add_admin_field(
			array(
				'type' => 'select',
				'name' => 'footer_top_columns',
				'parent' => $show_footer_top_container,
				'default_value' => '4',
				'label' => esc_html__('Footer Top Columns', 'vibez'),
				'description' => esc_html__('Choose number of columns for Footer Top area', 'vibez'),
				'options' => array(
					'1' => '1',
					'2' => '2',
					'3' => '3',
					'4' => '4'
				)
			)
		);

		vibez_elated_add_admin_field(
			array(
				'type' => 'select',
				'name' => 'footer_top_columns_alignment',
				'default_value' => 'left',
				'label' => esc_html__('Footer Top Columns Alignment', 'vibez'),
				'description' => esc_html__('Text Alignment in Footer Columns', 'vibez'),
				'options' => array(
					''       => esc_html__('Default', 'vibez'),
					'left'   => esc_html__('Left', 'vibez'),
					'center' => esc_html__('Center', 'vibez'),
					'right'  => esc_html__('Right', 'vibez')
				),
				'parent' => $show_footer_top_container,
			)
		);

		vibez_elated_add_admin_field(array(
			'name' => 'footer_top_background_color',
			'type' => 'color',
			'label' => esc_html__('Background Color', 'vibez'),
			'description' => esc_html__('Set background color for top footer area', 'vibez'),
			'parent' => $show_footer_top_container
		));

		vibez_elated_add_admin_field(
			array(
				'type' => 'yesno',
				'name' => 'show_footer_bottom',
				'default_value' => 'yes',
				'label' => esc_html__('Show Footer Bottom', 'vibez'),
				'description' => esc_html__('Enabling this option will show Footer Bottom area', 'vibez'),
				'args' => array(
					'dependence' => true,
					'dependence_hide_on_yes' => '',
					'dependence_show_on_yes' => '#eltdf_show_footer_bottom_container'
				),
				'parent' => $footer_panel,
			)
		);

		$show_footer_bottom_container = vibez_elated_add_admin_container(
			array(
				'name' => 'show_footer_bottom_container',
				'hidden_property' => 'show_footer_bottom',
				'hidden_value' => 'no',
				'parent' => $footer_panel
			)
		);

		vibez_elated_add_admin_field(
			array(
				'type' => 'select',
				'name' => 'footer_bottom_columns',
				'default_value' => '4',
				'label' => esc_html__('Footer Bottom Columns', 'vibez'),
				'description' => esc_html__('Choose number of columns for Footer Bottom area', 'vibez'),
				'options' => array(
					'1' => '1',
					'2' => '2',
					'3' => '3'
				),
				'parent' => $show_footer_bottom_container,
			)
		);

		vibez_elated_add_admin_field(array(
			'name' => 'footer_bottom_background_color',
			'type' => 'color',
			'label' => esc_html__('Background Color', 'vibez'),
			'description' => esc_html__('Set background color for bottom footer area', 'vibez'),
			'parent' => $show_footer_bottom_container
		));
	}

	add_action( 'vibez_elated_action_options_map', 'vibez_elated_footer_options_map', 9);
}