<?php

if ( ! function_exists('vibez_elated_search_options_map') ) {

	function vibez_elated_search_options_map() {

		vibez_elated_add_admin_page(
			array(
				'slug' => '_search_page',
				'title' => esc_html__('Search', 'vibez'),
				'icon' => 'fa fa-search'
			)
		);

		$search_page_panel = vibez_elated_add_admin_panel(
			array(
				'title' => esc_html__('Search Page', 'vibez'),
				'name' => 'search_template',
				'page' => '_search_page'
			)
		);

		vibez_elated_add_admin_field(array(
			'name'        => 'search_page_sidebar_layout',
			'type'        => 'select',
			'label'       => esc_html__('Sidebar Layout', 'vibez'),
            'description' 	=> esc_html__("Choose a sidebar layout for search page", 'vibez'),
            'default_value' => 'no-sidebar',
            'options'       => array(
                'no-sidebar'        => esc_html__('No Sidebar', 'vibez'),
                'sidebar-33-right'	=> esc_html__('Sidebar 1/3 Right', 'vibez'),
                'sidebar-25-right' 	=> esc_html__('Sidebar 1/4 Right', 'vibez'),
                'sidebar-33-left' 	=> esc_html__('Sidebar 1/3 Left', 'vibez'),
                'sidebar-25-left' 	=> esc_html__('Sidebar 1/4 Left', 'vibez')
            ),
			'parent'      => $search_page_panel
		));

        $vibez_custom_sidebars = vibez_elated_get_custom_sidebars();
        if(count($vibez_custom_sidebars) > 0) {
            vibez_elated_add_admin_field(array(
                'name' => 'search_custom_sidebar_area',
                'type' => 'selectblank',
                'label' => esc_html__('Sidebar to Display', 'vibez'),
                'description' => esc_html__('Choose a sidebar to display on search page. Default sidebar is "Sidebar"', 'vibez'),
                'parent' => $search_page_panel,
                'options' => $vibez_custom_sidebars,
				'args' => array(
					'select2' => true
				)
            ));
        }

		$search_panel = vibez_elated_add_admin_panel(
			array(
				'title' => esc_html__('Search', 'vibez'),
				'name' => 'search',
				'page' => '_search_page'
			)
		);

		vibez_elated_add_admin_field(
			array(
				'parent'		=> $search_panel,
				'type'			=> 'select',
				'name'			=> 'search_type',
				'default_value'	=> 'fullscreen',
				'label' 		=> esc_html__('Select Search Type', 'vibez'),
				'description' 	=> esc_html__("Choose a type of Select search bar (Note: Slide From Header Bottom search type doesn't work with Vertical Header)", 'vibez'),
				'options' 		=> array(
					'fullscreen' => esc_html__('Fullscreen Search', 'vibez'),
					'slide-from-header-bottom' => esc_html__('Slide From Header Bottom', 'vibez'),
                    'covers-header' => esc_html__('Search Covers Header', 'vibez'),
                    'slide-from-window-top' => esc_html__('Slide from Window Top' , 'vibez')
				)
			)
		);
		
		vibez_elated_add_admin_field(
			array(
				'parent'		=> $search_panel,
				'type'			=> 'select',
				'name'			=> 'search_icon_pack',
				'default_value'	=> 'font_elegant',
				'label'			=> esc_html__('Search Icon Pack', 'vibez'),
				'description'	=> esc_html__('Choose icon pack for search icon', 'vibez'),
				'options'		=> vibez_elated_icon_collections()->getIconCollectionsExclude(array('linear_icon'))
			)
		);

        vibez_elated_add_admin_field(
            array(
                'parent'		=> $search_panel,
                'type'			=> 'yesno',
                'name'			=> 'search_in_grid',
                'default_value'	=> 'yes',
                'label'			=> esc_html__('Enable Grid Layout', 'vibez'),
                'description'	=> esc_html__('Set search area to be in grid. (Applied for Search covers header and Slide from Window Top types.', 'vibez'),
            )
        );
		
		vibez_elated_add_admin_section_title(
			array(
				'parent' 	=> $search_panel,
				'name'		=> 'initial_header_icon_title',
				'title'		=> esc_html__('Initial Search Icon in Header', 'vibez')
			)
		);
		
		vibez_elated_add_admin_field(
			array(
				'parent'		=> $search_panel,
				'type'			=> 'text',
				'name'			=> 'header_search_icon_size',
				'default_value'	=> '',
				'label'			=> esc_html__('Icon Size', 'vibez'),
				'description'	=> esc_html__('Set size for icon', 'vibez'),
				'args'			=> array(
					'col_width' => 3,
					'suffix'	=> 'px'
				)
			)
		);
		
		$search_icon_color_group = vibez_elated_add_admin_group(
			array(
				'parent'	=> $search_panel,
				'title'		=> esc_html__('Icon Colors', 'vibez'),
				'description' => esc_html__('Define color style for icon', 'vibez'),
				'name'		=> 'search_icon_color_group'
			)
		);
		
		$search_icon_color_row = vibez_elated_add_admin_row(
			array(
				'parent'	=> $search_icon_color_group,
				'name'		=> 'search_icon_color_row'
			)
		);
		
		vibez_elated_add_admin_field(
			array(
				'parent'	=> $search_icon_color_row,
				'type'		=> 'colorsimple',
				'name'		=> 'header_search_icon_color',
				'label'		=> esc_html__('Color', 'vibez')
			)
		);
		
		vibez_elated_add_admin_field(
			array(
				'parent' => $search_icon_color_row,
				'type'		=> 'colorsimple',
				'name'		=> 'header_search_icon_hover_color',
				'label'		=> esc_html__('Hover Color', 'vibez')
			)
		);
		
		vibez_elated_add_admin_field(
			array(
				'parent'		=> $search_panel,
				'type'			=> 'yesno',
				'name'			=> 'enable_search_icon_text',
				'default_value'	=> 'no',
				'label'			=> esc_html__('Enable Search Icon Text', 'vibez'),
				'description'	=> esc_html__("Enable this option to show 'Search' text next to search icon in header", 'vibez'),
				'args'			=> array(
					'dependence' => true,
					'dependence_hide_on_yes' => '',
					'dependence_show_on_yes' => '#eltdf_enable_search_icon_text_container'
				)
			)
		);
		
		$enable_search_icon_text_container = vibez_elated_add_admin_container(
			array(
				'parent'			=> $search_panel,
				'name'				=> 'enable_search_icon_text_container',
				'hidden_property'	=> 'enable_search_icon_text',
				'hidden_value'		=> 'no'
			)
		);
		
		$enable_search_icon_text_group = vibez_elated_add_admin_group(
			array(
				'parent'	=> $enable_search_icon_text_container,
				'title'		=> esc_html__('Search Icon Text', 'vibez'),
				'name'		=> 'enable_search_icon_text_group',
				'description'	=> esc_html__('Define style for search icon text', 'vibez')
			)
		);
		
		$enable_search_icon_text_row = vibez_elated_add_admin_row(
			array(
				'parent'	=> $enable_search_icon_text_group,
				'name'		=> 'enable_search_icon_text_row'
			)
		);
		
		vibez_elated_add_admin_field(
			array(
				'parent'		=> $enable_search_icon_text_row,
				'type'			=> 'colorsimple',
				'name'			=> 'search_icon_text_color',
				'label'			=> esc_html__('Text Color', 'vibez')
			)
		);
		
		vibez_elated_add_admin_field(
			array(
				'parent'		=> $enable_search_icon_text_row,
				'type'			=> 'colorsimple',
				'name'			=> 'search_icon_text_color_hover',
				'label'			=> esc_html__('Text Hover Color', 'vibez')
			)
		);
		
		vibez_elated_add_admin_field(
			array(
				'parent'		=> $enable_search_icon_text_row,
				'type'			=> 'textsimple',
				'name'			=> 'search_icon_text_font_size',
				'label'			=> esc_html__('Font Size', 'vibez'),
				'default_value'	=> '',
				'args'			=> array(
					'suffix'	=> 'px'
				)
			)
		);
		
		vibez_elated_add_admin_field(
			array(
				'parent'		=> $enable_search_icon_text_row,
				'type'			=> 'textsimple',
				'name'			=> 'search_icon_text_line_height',
				'label'			=> esc_html__('Line Height', 'vibez'),
				'default_value'	=> '',
				'args'			=> array(
					'suffix'	=> 'px'
				)
			)
		);
		
		$enable_search_icon_text_row2 = vibez_elated_add_admin_row(
			array(
				'parent'	=> $enable_search_icon_text_group,
				'name'		=> 'enable_search_icon_text_row2',
				'next'		=> true
			)
		);
		
		vibez_elated_add_admin_field(
			array(
				'parent'		=> $enable_search_icon_text_row2,
				'type'			=> 'selectblanksimple',
				'name'			=> 'search_icon_text_text_transform',
				'label'			=> esc_html__('Text Transform', 'vibez'),
				'default_value'	=> '',
				'options'		=> vibez_elated_get_text_transform_array()
			)
		);
		
		vibez_elated_add_admin_field(
			array(
				'parent'		=> $enable_search_icon_text_row2,
				'type'			=> 'fontsimple',
				'name'			=> 'search_icon_text_google_fonts',
				'label'			=> esc_html__('Font Family', 'vibez'),
				'default_value'	=> '-1',
			)
		);
		
		vibez_elated_add_admin_field(
			array(
				'parent'		=> $enable_search_icon_text_row2,
				'type'			=> 'selectblanksimple',
				'name'			=> 'search_icon_text_font_style',
				'label'			=> esc_html__('Font Style', 'vibez'),
				'default_value'	=> '',
				'options'		=> vibez_elated_get_font_style_array(),
			)
		);
		
		vibez_elated_add_admin_field(
			array(
				'parent'		=> $enable_search_icon_text_row2,
				'type'			=> 'selectblanksimple',
				'name'			=> 'search_icon_text_font_weight',
				'label'			=> esc_html__('Font Weight', 'vibez'),
				'default_value'	=> '',
				'options'		=> vibez_elated_get_font_weight_array(),
			)
		);
		
		$enable_search_icon_text_row3 = vibez_elated_add_admin_row(
			array(
				'parent'	=> $enable_search_icon_text_group,
				'name'		=> 'enable_search_icon_text_row3',
				'next'		=> true
			)
		);
		
		vibez_elated_add_admin_field(
			array(
				'parent'		=> $enable_search_icon_text_row3,
				'type'			=> 'textsimple',
				'name'			=> 'search_icon_text_letter_spacing',
				'label'			=> esc_html__('Letter Spacing', 'vibez'),
				'default_value'	=> '',
				'args'			=> array(
					'suffix'	=> 'px'
				)
			)
		);
	}

	add_action('vibez_elated_action_options_map', 'vibez_elated_search_options_map', 7);
}