<?php

/**
 * Force Visual Composer to initialize as "built into the theme". This will hide certain tabs under the Settings->Visual Composer page
 */
if ( function_exists( 'vc_set_as_theme' ) ) {
	vc_set_as_theme( true );
}

/**
 * Change path for overridden templates
 */
if ( function_exists( 'vc_set_shortcodes_templates_dir' ) ) {
	$dir = ELATED_ROOT_DIR . '/vc-templates';
	vc_set_shortcodes_templates_dir( $dir );
}

if ( ! function_exists( 'vibez_elated_configure_visual_composer_frontend_editor' ) ) {
	/**
	 * Configuration for Visual Composer FrontEnd Editor
	 * Hooks on vc_after_init action
	 */
	function vibez_elated_configure_visual_composer_frontend_editor() {
		/**
		 * Remove frontend editor
		 */
		if ( function_exists( 'vc_disable_frontend' ) ) {
			vc_disable_frontend();
		}
	}
	
	add_action( 'vc_after_init', 'vibez_elated_configure_visual_composer_frontend_editor' );
}

if ( ! function_exists( 'vibez_elated_vc_row_map' ) ) {
	/**
	 * Map VC Row shortcode
	 * Hooks on vc_after_init action
	 */
	function vibez_elated_vc_row_map() {
		
		vc_add_param( 'vc_row', array(
			'type'       => 'dropdown',
			'param_name' => 'row_content_width',
			'heading'    => esc_html__( 'Elated Row Content Width', 'vibez' ),
			'value'      => array(
				esc_html__( 'Full Width', 'vibez' ) => 'full-width',
				esc_html__( 'In Grid', 'vibez' )    => 'grid'
			),
			'group'      => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row', array(
			'type'        => 'textfield',
			'param_name'  => 'anchor',
			'heading'     => esc_html__( 'Elated Anchor ID', 'vibez' ),
			'description' => esc_html__( 'For example "home"', 'vibez' ),
			'group'       => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row', array(
			'type'       => 'colorpicker',
			'param_name' => 'simple_background_color',
			'heading'    => esc_html__( 'Elated Background Color', 'vibez' ),
			'group'      => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row', array(
			'type'       => 'attach_image',
			'param_name' => 'simple_background_image',
			'heading'    => esc_html__( 'Elated Background Image', 'vibez' ),
			'group'      => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row', array(
			'type'        => 'dropdown',
			'param_name'  => 'disable_background_image',
			'heading'     => esc_html__( 'Elated Disable Background Image', 'vibez' ),
			'value'       => array(
				esc_html__( 'Never', 'vibez' )        => '',
				esc_html__( 'Below 1440px', 'vibez' ) => '1440',
				esc_html__( 'Below 1280px', 'vibez' ) => '1280',
				esc_html__( 'Below 1024px', 'vibez' ) => '1024',
				esc_html__( 'Below 768px', 'vibez' )  => '768',
				esc_html__( 'Below 680px', 'vibez' )  => '680',
				esc_html__( 'Below 480px', 'vibez' )  => '480'
			),
			'save_always' => true,
			'description' => esc_html__( 'Choose on which stage you hide row background image', 'vibez' ),
			'dependency'  => array( 'element' => 'simple_background_image', 'not_empty' => true ),
			'group'       => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row', array(
			'type'       => 'attach_image',
			'param_name' => 'parallax_background_image',
			'heading'    => esc_html__( 'Elated Parallax Background Image', 'vibez' ),
			'group'      => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row', array(
			'type'        => 'attach_image',
			'param_name'  => 'parallax_responsive_background_image',
			'heading'     => esc_html__( 'Elated Parallax Responsive Background Image', 'vibez' ),
			'description' => esc_html__( 'Set additional parallax background image for tablets screens and lowers', 'vibez' ),
			'dependency'  => array( 'element' => 'parallax_background_image', 'not_empty' => true ),
			'group'       => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row', array(
			'type'        => 'textfield',
			'param_name'  => 'parallax_bg_speed',
			'heading'     => esc_html__( 'Elated Parallax Speed', 'vibez' ),
			'description' => esc_html__( 'Set your parallax speed. Default value is 1.', 'vibez' ),
			'dependency'  => array( 'element' => 'parallax_background_image', 'not_empty' => true ),
			'group'       => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row', array(
			'type'       => 'textfield',
			'param_name' => 'parallax_bg_height',
			'heading'    => esc_html__( 'Elated Parallax Section Height (px)', 'vibez' ),
			'dependency' => array( 'element' => 'parallax_background_image', 'not_empty' => true ),
			'group'      => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row', array(
			'type'        => 'dropdown',
			'param_name'  => 'enable_arrows_animation',
			'heading'     => esc_html__( 'Elated Arrows Background Animation', 'vibez' ),
			'value'       => array_flip( vibez_elated_get_yes_no_select_array( false ) ),
			'save_always' => true,
			'group'       => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row', array(
			'type'        => 'dropdown',
			'param_name'  => 'arrows_skin',
			'heading'     => esc_html__( 'Elated Arrows Skin', 'vibez' ),
			'value'       => array(
				esc_html__( 'Green', 'vibez' )      => 'green',
				esc_html__( 'White', 'vibez' )      => 'white',
				esc_html__( 'Black', 'vibez' )      => 'black',
				esc_html__( 'Gray', 'vibez' )       => 'gray',
				esc_html__( 'Gray Large', 'vibez' ) => 'gray-large'
			),
			'save_always' => true,
			'dependency'  => array( 'element' => 'enable_arrows_animation', 'value' => array( 'yes' ) ),
			'group'       => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row', array(
			'type'        => 'dropdown',
			'param_name'  => 'arrows_horizontal_position',
			'heading'     => esc_html__( 'Elated Arrows Horizontal Position', 'vibez' ),
			'value'       => array(
				esc_html__( 'Left', 'vibez' )  => 'left',
				esc_html__( 'Right', 'vibez' ) => 'right'
			),
			'save_always' => true,
			'dependency'  => array( 'element' => 'enable_arrows_animation', 'value' => array( 'yes' ) ),
			'group'       => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row', array(
			'type'        => 'dropdown',
			'param_name'  => 'arrows_vertical_position',
			'heading'     => esc_html__( 'Elated Arrows Vertical Position', 'vibez' ),
			'value'       => array(
				esc_html__( 'Top', 'vibez' )    => 'top',
				esc_html__( 'Middle', 'vibez' ) => 'middle',
				esc_html__( 'Bottom', 'vibez' ) => 'bottom'
			),
			'save_always' => true,
			'dependency'  => array( 'element' => 'enable_arrows_animation', 'value' => array( 'yes' ) ),
			'group'       => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row', array(
			'type'        => 'dropdown',
			'param_name'  => 'reduce_arrows_animation',
			'heading'     => esc_html__( 'Elated Reduce Number Of Arrows Animation Items To Half', 'vibez' ),
			'value'       => array(
				esc_html__( 'Never', 'vibez' )        => '',
				esc_html__( 'Below 1440px', 'vibez' ) => '1440',
				esc_html__( 'Below 1280px', 'vibez' ) => '1280',
				esc_html__( 'Below 1024px', 'vibez' ) => '1024',
				esc_html__( 'Below 768px', 'vibez' )  => '768',
				esc_html__( 'Below 680px', 'vibez' )  => '680',
				esc_html__( 'Below 480px', 'vibez' )  => '480'
			),
			'save_always' => true,
			'description' => esc_html__( 'Choose on which stage you reduce number of arrows animation items to half', 'vibez' ),
			'dependency'  => array( 'element' => 'enable_arrows_animation', 'value' => array( 'yes' ) ),
			'group'       => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row', array(
			'type'        => 'dropdown',
			'param_name'  => 'disable_arrows_animation',
			'heading'     => esc_html__( 'Elated Disable Arrows Animation', 'vibez' ),
			'value'       => array(
				esc_html__( 'Never', 'vibez' )        => '',
				esc_html__( 'Below 1440px', 'vibez' ) => '1440',
				esc_html__( 'Below 1280px', 'vibez' ) => '1280',
				esc_html__( 'Below 1024px', 'vibez' ) => '1024',
				esc_html__( 'Below 768px', 'vibez' )  => '768',
				esc_html__( 'Below 680px', 'vibez' )  => '680',
				esc_html__( 'Below 480px', 'vibez' )  => '480'
			),
			'save_always' => true,
			'description' => esc_html__( 'Choose on which stage you hide row arrows animation', 'vibez' ),
			'dependency'  => array( 'element' => 'enable_arrows_animation', 'value' => array( 'yes' ) ),
			'group'       => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row', array(
			'type'       => 'dropdown',
			'param_name' => 'content_text_aligment',
			'heading'    => esc_html__( 'Elated Content Aligment', 'vibez' ),
			'value'      => array(
				esc_html__( 'Default', 'vibez' ) => '',
				esc_html__( 'Left', 'vibez' )    => 'left',
				esc_html__( 'Center', 'vibez' )  => 'center',
				esc_html__( 'Right', 'vibez' )   => 'right'
			),
			'group'      => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		/*** Row Inner ***/
		
		vc_add_param( 'vc_row_inner', array(
			'type'       => 'dropdown',
			'param_name' => 'row_content_width',
			'heading'    => esc_html__( 'Elated Row Content Width', 'vibez' ),
			'value'      => array(
				esc_html__( 'Full Width', 'vibez' ) => 'full-width',
				esc_html__( 'In Grid', 'vibez' )    => 'grid'
			),
			'group'      => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row_inner', array(
			'type'       => 'colorpicker',
			'param_name' => 'simple_background_color',
			'heading'    => esc_html__( 'Elated Background Color', 'vibez' ),
			'group'      => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row_inner', array(
			'type'       => 'attach_image',
			'param_name' => 'simple_background_image',
			'heading'    => esc_html__( 'Elated Background Image', 'vibez' ),
			'group'      => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row_inner', array(
			'type'        => 'dropdown',
			'param_name'  => 'disable_background_image',
			'heading'     => esc_html__( 'Elated Disable Background Image', 'vibez' ),
			'value'       => array(
				esc_html__( 'Never', 'vibez' )        => '',
				esc_html__( 'Below 1440px', 'vibez' ) => '1440',
				esc_html__( 'Below 1280px', 'vibez' ) => '1280',
				esc_html__( 'Below 1024px', 'vibez' ) => '1024',
				esc_html__( 'Below 768px', 'vibez' )  => '768',
				esc_html__( 'Below 680px', 'vibez' )  => '680',
				esc_html__( 'Below 480px', 'vibez' )  => '480'
			),
			'save_always' => true,
			'description' => esc_html__( 'Choose on which stage you hide row background image', 'vibez' ),
			'dependency'  => array( 'element' => 'simple_background_image', 'not_empty' => true ),
			'group'       => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row_inner', array(
			'type'       => 'attach_image',
			'param_name' => 'parallax_background_image',
			'heading'    => esc_html__( 'Elated Parallax Background Image', 'vibez' ),
			'group'      => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row_inner', array(
			'type'        => 'attach_image',
			'param_name'  => 'parallax_responsive_background_image',
			'heading'     => esc_html__( 'Elated Parallax Responsive Background Image', 'vibez' ),
			'description' => esc_html__( 'Set additional parallax background image for tablets screens and lowers', 'vibez' ),
			'dependency'  => array( 'element' => 'parallax_background_image', 'not_empty' => true ),
			'group'       => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row_inner', array(
			'type'        => 'textfield',
			'param_name'  => 'parallax_bg_speed',
			'heading'     => esc_html__( 'Elated Parallax Speed', 'vibez' ),
			'description' => esc_html__( 'Set your parallax speed. Default value is 1.', 'vibez' ),
			'dependency'  => array( 'element' => 'parallax_background_image', 'not_empty' => true ),
			'group'       => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row_inner', array(
			'type'       => 'textfield',
			'param_name' => 'parallax_bg_height',
			'heading'    => esc_html__( 'Elated Parallax Section Height (px)', 'vibez' ),
			'dependency' => array( 'element' => 'parallax_background_image', 'not_empty' => true ),
			'group'      => esc_html__( 'Elated Settings', 'vibez' )
		) );
		
		vc_add_param( 'vc_row_inner', array(
			'type'       => 'dropdown',
			'param_name' => 'content_text_aligment',
			'heading'    => esc_html__( 'Elated Content Aligment', 'vibez' ),
			'value'      => array(
				esc_html__( 'Default', 'vibez' ) => '',
				esc_html__( 'Left', 'vibez' )    => 'left',
				esc_html__( 'Center', 'vibez' )  => 'center',
				esc_html__( 'Right', 'vibez' )   => 'right'
			),
			'group'      => esc_html__( 'Elated Settings', 'vibez' )
		) );
	}
	
	add_action( 'vc_after_init', 'vibez_elated_vc_row_map' );
}