<?php

class VibezElatedClassBlogListWidget extends VibezElatedClassWidget {
    public function __construct() {
        parent::__construct(
            'eltdf_blog_list_widget',
            esc_html__('Elated Blog List Widget', 'vibez'),
            array( 'description' => esc_html__( 'Display a list of your blog posts', 'vibez'))
        );

        $this->setParams();
    }

    /**
     * Sets widget options
     */
    protected function setParams() {
        $this->params = array(
            array(
                'type'  => 'textfield',
                'name'  => 'widget_title',
                'title' => esc_html__('Widget Title', 'vibez')
            ),
            array(
                'type'    => 'dropdown',
                'name'    => 'type',
                'title'   => esc_html__('Type', 'vibez'),
                'options' => array(
                    'simple'  => esc_html__('Simple', 'vibez'),
                    'minimal' => esc_html__('Minimal', 'vibez')
                )
            ),
            array(
                'type'  => 'textfield',
                'name'  => 'number_of_posts',
                'title' => esc_html__('Number of Posts', 'vibez')
            ),
            array(
                'type'    => 'dropdown',
                'name'    => 'space_between_columns',
                'title'   => esc_html__('Space Between items', 'vibez'),
                'options' => array(
                    'normal' => esc_html__('Normal', 'vibez'),
                    'medium' => esc_html__('Medium', 'vibez'),
                    'small'  => esc_html__('Small', 'vibez'),
                    'tiny'   => esc_html__('Tiny', 'vibez'),
                    'no'     => esc_html__('No Space', 'vibez')
                )
            ),
	        array(
		        'type'    => 'dropdown',
		        'name'    => 'order_by',
		        'title'   => esc_html__('Order By', 'vibez'),
		        'options' => vibez_elated_get_query_order_by_array()
	        ),
	        array(
		        'type'    => 'dropdown',
		        'name'    => 'order',
		        'title'   => esc_html__('Order', 'vibez'),
		        'options' => vibez_elated_get_query_order_array()
	        ),
            array(
                'type'        => 'textfield',
                'name'        => 'category',
                'title'       => esc_html__('Category Slug', 'vibez'),
                'description' => esc_html__('Leave empty for all or use comma for list', 'vibez')
            ),
            array(
                'type'    => 'dropdown',
                'name'    => 'title_tag',
                'title'   => esc_html__('Title Tag', 'vibez'),
                'options' => vibez_elated_get_title_tag(true, array('p' => 'p'))
            ),
            array(
                'type'    => 'dropdown',
                'name'    => 'title_transform',
                'title'   => esc_html__('Title Text Transform', 'vibez'),
                'options' => vibez_elated_get_text_transform_array(true)
            )
        );
    }

    /**
     * Generates widget's HTML
     *
     * @param array $args args from widget area
     * @param array $instance widget's options
     */
    public function widget($args, $instance) {
        $params = '';

        if (!is_array($instance)) { $instance = array(); }

        $instance['post_info_section'] = 'yes';
        $instance['number_of_columns'] = '1';
        $instance['image_size']        = 'thumbnail';

        // Filter out all empty params
        $instance = array_filter($instance, function($array_value) { return trim($array_value) != ''; });

        //generate shortcode params
        foreach($instance as $key => $value) {
            $params .= " $key='$value' ";
        }

        $available_types = array('simple', 'classic');

        if (!in_array($instance['type'], $available_types)) {
            $instance['type'] = 'simple';
        }

        echo '<div class="widget eltdf-blog-list-widget">';
		    if ( ! empty( $instance['widget_title'] ) ) {
			    echo wp_kses_post( $args['before_title'] ) . esc_html( $instance['widget_title'] ) . wp_kses_post( $args['after_title'] );
		    }

            echo do_shortcode("[eltdf_blog_list $params]"); // XSS OK
        echo '</div>';
    }
}