<?php
/**
 * Single Event Template
 * A single event. This displays the event title, description, meta, and
 * optionally, the Google map for the event.
 *
 * Override this template in your own theme by creating a file at [your-theme]/tribe-events/single-event.php
 *
 * @package TribeEventsCalendar
 *
 */

if(!defined('ABSPATH')) {
	die('-1');
}

$events_label_singular = tribe_get_event_label_singular();
$events_label_plural   = tribe_get_event_label_plural();

$event_id = get_the_ID();

?>

<div id="tribe-events-content" class="tribe-events-single eltdf-tribe-events-single">
	<!-- Notices -->
	<?php tribe_the_notices() ?>

	<div class="eltdf-events-single-main-info clearfix">
		<div class="eltdf-events-single-date-holder">
			<span class="eltdf-events-single-date-day">
				<?php echo tribe_get_start_date(null, true, 'd'); ?>
			</span>

			<span class="eltdf-events-single-date-month">
				<?php echo tribe_get_start_date(null, true, 'M'); ?>
			</span>
		</div>
		<div class="eltdf-events-single-title-holder">
			<?php if(tribe_get_cost($event_id)) { ?>
				<div class="eltdf-events-single-cost">
					<?php echo tribe_get_cost(null, true); ?>
				</div>
			<?php } ?>
			<h3 class="eltdf-events-single-title"><?php the_title(); ?></h3>
			<div class="eltdf-events-single-date">
				<span class="eltdf-events-single-info-icon">
					<?php echo vibez_elated_icon_collections()->renderIcon('ion-clock', 'ion_icons'); ?>
				</span>
				<?php echo tribe_events_event_schedule_details($event_id); ?>
			</div>
		</div>
	</div>

	<div class="eltdf-events-single-main-content">
		<div class="eltdf-grid-row">
			<div class="eltdf-events-single-featured-image eltdf-grid-col-6">
				<?php echo tribe_event_featured_image($event_id, 'full', false); ?>
			</div>
			
			<div class="eltdf-events-single-map eltdf-grid-col-6">
				<?php tribe_get_template_part('modules/meta/map'); ?>
			</div>
		</div>
		
		<div class="eltdf-events-single-content-holder">
			<?php do_action('tribe_events_single_event_before_the_content') ?>
			<?php the_content(); ?>
			
			<?php do_action('tribe_events_single_event_before_the_meta') ?>
			
			<h3 class="eltdf-events-single-content-title"><?php esc_html_e('EVENT DETAILS', 'vibez'); ?></h3>

			<div class="eltdf-events-single-meta-holder eltdf-grid-row">
				<div class="eltdf-grid-col-4">
					<div class="eltdf-events-single-meta-item">
						<span class="eltdf-events-single-meta-icon">
							<?php echo vibez_elated_icon_collections()->renderIcon('lnr-calendar-full', 'linear_icons'); ?>
						</span>
						<span class="eltdf-events-single-meta-label"><?php esc_html_e('Date:', 'vibez'); ?></span>
						<span class="eltdf-events-single-meta-value">
							<?php echo tribe_events_event_schedule_details(); ?>
						</span>
					</div>

					<div class="eltdf-events-single-meta-item">
						<span class="eltdf-events-single-meta-icon">
							<?php echo vibez_elated_icon_collections()->renderIcon('ion-clock', 'ion_icons'); ?>
						</span>
						<span class="eltdf-events-single-meta-label"><?php esc_html_e('Time:', 'vibez'); ?></span>
						<span class="eltdf-events-single-meta-value">
							<?php echo tribe_get_start_time(); ?> - <?php echo tribe_get_end_time(); ?>
						</span>
					</div>

					<?php if(tribe_has_venue()) : ?>
						<div class="eltdf-events-single-meta-item">
                            <span class="eltdf-events-single-meta-icon">
                                <?php echo vibez_elated_icon_collections()->renderIcon('lnr-apartment', 'linear_icons'); ?>
                            </span>
							<span class="eltdf-events-single-meta-label"><?php esc_html_e('Venue:', 'vibez'); ?></span>
							<span class="eltdf-events-single-meta-value">
                                <?php echo tribe_get_venue(); ?>
                            </span>
						</div>

						<?php if(tribe_address_exists()) : ?>
							<div class="eltdf-events-single-meta-item">
								<span class="eltdf-events-single-meta-icon">
									<?php echo vibez_elated_icon_collections()->renderIcon('lnr-apartment', 'linear_icons'); ?>
								</span>
								<span class="eltdf-events-single-meta-label"><?php esc_html_e('Address:', 'vibez'); ?></span>
								<span class="eltdf-events-single-meta-value">
									<?php echo tribe_get_address(); ?>
								</span>
							</div>
						<?php endif; ?>
					<?php endif; ?>
				</div>

				<div class="eltdf-grid-col-4">
					<?php if(tribe_has_organizer()) : ?>
						<div class="eltdf-events-single-meta-item">
							<span class="eltdf-events-single-meta-icon">
								<?php echo vibez_elated_icon_collections()->renderIcon('lnr-user', 'linear_icons'); ?>
							</span>
							<span class="eltdf-events-single-meta-label"><?php esc_html_e('Organizer Name:', 'vibez'); ?></span>
							<span class="eltdf-events-single-meta-value">
								<?php echo tribe_get_organizer(); ?>
							</span>
						</div>
					<?php endif; ?>

					<?php if(tribe_get_organizer_phone()) : ?>
						<div class="eltdf-events-single-meta-item">
							<span class="eltdf-events-single-meta-icon">
								<?php echo vibez_elated_icon_collections()->renderIcon('lnr-phone-handset', 'linear_icons'); ?>
							</span>
							<span class="eltdf-events-single-meta-label"><?php esc_html_e('Phone:', 'vibez'); ?></span>
							<span class="eltdf-events-single-meta-value">
								<?php echo tribe_get_organizer_phone(); ?>
							</span>
						</div>
					<?php endif; ?>

					<?php if(tribe_get_organizer_email()) : ?>
						<div class="eltdf-events-single-meta-item">
							<span class="eltdf-events-single-meta-icon">
								<?php echo vibez_elated_icon_collections()->renderIcon('lnr-bubble', 'linear_icons'); ?>
							</span>
							<span class="eltdf-events-single-meta-label"><?php esc_html_e('Email:', 'vibez'); ?></span>
							<span class="eltdf-events-single-meta-value">
								<a href="mailto: <?php echo tribe_get_organizer_email(); ?>">
	                                <?php echo tribe_get_organizer_email(); ?>
	                            </a>
							</span>
						</div>
					<?php endif; ?>

					<?php if(tribe_get_organizer_website_link()) : ?>
						<div class="eltdf-events-single-meta-item">
							<span class="eltdf-events-single-meta-icon">
								<?php echo vibez_elated_icon_collections()->renderIcon('lnr-earth', 'linear_icons'); ?>
							</span>
							<span class="eltdf-events-single-meta-label"><?php esc_html_e('Website:', 'vibez'); ?></span>
							<span class="eltdf-events-single-meta-value">
								<a target="_blank" href="<?php echo tribe_get_organizer_website_url(); ?>">
	                                <?php echo tribe_get_organizer_website_url(); ?>
	                            </a>
							</span>
						</div>
					<?php endif; ?>
				</div>
				
				<div class="eltdf-grid-col-4">
				</div>
			</div>
			
			<?php do_action('tribe_events_single_event_after_the_meta'); ?>
		</div>
		
		<div class="eltdf-events-single-navigation clearfix">
			<div class="eltdf-events-single-prev">
				<?php tribe_the_prev_event_link('%title%'); ?>
			</div>
			
			<div class="eltdf-events-single-next">
				<?php tribe_the_next_event_link('%title%'); ?>
			</div>
		</div>
		
		<?php do_action('tribe_events_single_event_after_the_content') ?>
	</div>

</div>
